kubernetes

package
v0.0.0-...-c889ea1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2018 License: Apache-2.0 Imports: 10 Imported by: 0

README

Kubernetes client libraries

This package (and sub-packages) holds the client libraries for the kubernetes integration in the docker platform. Most of the code is currently generated.

Documentation

Index

Constants

const (
	// StackAPIV1Beta1 is returned if it's the most recent version available.
	StackAPIV1Beta1 = StackVersion("v1beta1")
)

Variables

This section is empty.

Functions

func NewKubernetesConfig

func NewKubernetesConfig(configFlag string) (*restclient.Config, error)

NewKubernetesConfig resolves the path to the desired Kubernetes configuration file, depending environment variable and command line flag.

Types

type StackVersion

type StackVersion string

StackVersion represents the detected Compose Component on Kubernetes side.

func GetStackAPIVersion

func GetStackAPIVersion(clientSet *kubernetes.Clientset) (StackVersion, error)

GetStackAPIVersion returns the most recent stack API installed.

Directories

Path Synopsis
client
clientset_generated/clientset
This package has the automatically generated clientset.
This package has the automatically generated clientset.
clientset_generated/clientset/scheme
This package contains the scheme of the automatically generated clientset.
This package contains the scheme of the automatically generated clientset.
clientset_generated/clientset/typed/compose/v1beta1
This package has the automatically generated typed clients.
This package has the automatically generated typed clients.
Package compose is the internal version of the API.
Package compose is the internal version of the API.
v1beta1
Package v1beta1 holds the v1beta1 versions of our stack structures.
Package v1beta1 holds the v1beta1 versions of our stack structures.

Jump to